@@ -1,4 +1,4 @@
-#Added by slkbuild 1.2
+#Added by slkbuild 1.4
 dotnew() {
         NEW="${1}.new"
         OLD="$1"
@@ -9,8 +9,11 @@ dotnew() {
         fi
 }
 dotnew etc/slkbuild/SLKBUILD
+dotnew etc/slkbuild/SLKBUILD.cmake
 dotnew etc/slkbuild/SLKBUILD.gconf
 dotnew etc/slkbuild/SLKBUILD.mateconf
+dotnew etc/slkbuild/SLKBUILD.meson
+dotnew etc/slkbuild/SLKBUILD.musl
 dotnew etc/slkbuild/SLKBUILD.perl
 dotnew etc/slkbuild/SLKBUILD.python
 dotnew etc/slkbuild/SLKBUILD.waf
